componenttools.partition_components_once_by_durations_in_seconds_ge_with_overhang
=================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_once_by_durations_in_seconds_ge_with_overhang.partition_components_once_by_durations_in_seconds_ge_with_overhang
